@@ -18,14 +18,12 @@ our @EXPORT_OK = qw(
                      $GSL_PREC_SINGLE $GSL_PREC_APPROX
                    );
 
-our %EXPORT_TAGS = ( 
-                     all => \@EXPORT_OK,
-                   );
 
-our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0..2;
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, );
+
+our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0 .. 2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.14';
-
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -33,9 +31,7 @@ Math::GSL - Perl interface to the  GNU Scientific Library (GSL)
 
 =head1 VERSION
 
-Version 0.14
-
-=cut
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -188,25 +184,6 @@ sub new
     my $this = { };
     bless $this, $class;
 }
-
-sub subsystems
-{
-    return sort qw/
-        Diff         Machine      Statistics   
-        Eigen        Matrix       Poly      
-        BSpline      Errno        PowInt        
-        CBLAS        FFT          Min           IEEEUtils
-        CDF          Fit          QRNG
-        Chebyshev    Monte        RNG           Vector
-        Heapsort     Multifit     Randist       Roots     
-        Combination  Histogram    Multimin      Wavelet
-        Complex      Histogram2D  Multiroots    Wavelet2D
-        Const        Siman        Sum           Sys
-        NTuple       Integration  Sort          Test        
-        DHT          Interp       ODEIV         SF 
-        Deriv        Linalg       Permutation   Spline
-    /;
-}
 sub gsl_fopen
 {
     my ($file, $mode) = @_;
