@@ -8,6 +8,7 @@ use Math::GSL::Errno qw/:all/;
 use Math::GSL::Machine qw/:all/;
 use Math::GSL::Const qw/:all/;
 use Math::GSL::Sys qw/gsl_nan gsl_isnan gsl_isinf/;
+use Data::Dumper;
 use Carp qw/croak/;
 our @EXPORT = qw();
 our @EXPORT_OK = qw( 
@@ -16,7 +17,7 @@ our @EXPORT_OK = qw(
                      is_similar_relative 
                      verify verify_results 
                      is_windows 
-                     ok_status
+                     ok_status is_status_ok
 );
 use constant GSL_IS_WINDOWS =>  ($^O =~ /MSWin32/i)  ?  1 : 0 ;
 
@@ -32,9 +33,7 @@ Math::GSL::Test - Assertions and such
 
 =cut
 
-our %EXPORT_TAGS = ( 
-                     all => \@EXPORT_OK,
-                   );
+our %EXPORT_TAGS = ( all => \@EXPORT_OK,);
 
 sub _dump_result($)
 {
@@ -66,7 +65,7 @@ will check to see if
 
     $similarity_function->($x,$y_) <= $eps
 
-The default value of $eps is 1e-8. Don't try sending anything to the moon with this value...
+The default value of $eps is 1e-8. Don't try sending anything to the Moon with this value...
 
 =cut
 
@@ -75,7 +74,7 @@ sub is_similar {
     $eps ||= 1e-8;
     if (ref $x eq 'ARRAY' && ref $y eq 'ARRAY') {
         if ( $#$x != $#$y ){
-            warn "is_similar(): argument of different lengths, $#$x != $#$y !!!";
+            warn "is_similar(): items differ in length, $#$x != $#$y !!!";
             return 0;
         } else {
             map { 
@@ -198,10 +197,27 @@ function also stringifies the status codes into meaningful messages when it fail
 =cut
 
 sub ok_status {
-    my ($got, $expected) = @_;
+    my ($got, $expected, $msg ) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     $expected ||= $GSL_SUCCESS;
-    ok( defined $got && $got == $expected, gsl_strerror(int($got)) );
+    my $strerr = gsl_strerror(int($got));
+    $msg       = $msg ? "$msg: " . $strerr : $strerr;
+
+    ok( defined $got && $got == $expected, $msg );
+}
+
+=head2 is_status_ok($status)
+
+    is_status_ok( $status );
+
+Return true if $status is $GSL_SUCCESS, false otherwise.
+
+=cut
+
+sub is_status_ok {
+    my ($got) = shift;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    return ( defined $got && $got == $GSL_SUCCESS ) ? 1 : 0 ;
 }
 
 =head2 ok_similar( $x, $y, $msg, $eps)
@@ -232,6 +248,7 @@ seem very useful. What should the default be?
 
 sub is_similar_relative {
     my ($x,$y, $eps) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
     return is_similar($x,$y,$eps, sub { abs( ($_[0] - $_[1])/abs($_[1]) ) } );
 }
 
